@@ -89,6 +89,7 @@ void CommonTekstiTv::subPredictionReceived(QNetworkReply *reply) {
 }
 
 void CommonTekstiTv::getTekstiTv(int page, int subPage) {
+    emit tekstiTvRequest(true);
     m_page = page;
     m_subPage = subPage;
     QString url = transformToRealUrl(m_imageUrl);
@@ -99,6 +100,7 @@ void CommonTekstiTv::getTekstiTv(int page, int subPage) {
 }
 
 void CommonTekstiTv::getTekstiTv(QString url) {
+    emit tekstiTvRequest(true);
     QNetworkAccessManager *manager = new QNetworkAccessManager();
     connect(manager, SIGNAL(finished(QNetworkReply*)),
             this, SLOT(tekstiTvReceived(QNetworkReply*)));
@@ -108,6 +110,7 @@ void CommonTekstiTv::getTekstiTv(QString url) {
 }
 
 void CommonTekstiTv::tekstiTvReceived(QNetworkReply *reply) {
+    emit tekstiTvRequest(false);
     QByteArray imgTextTv = reply->readAll();
     m_imageData = new QPixmap();
     bool success = m_imageData->loadFromData(imgTextTv);
